# -*- coding: utf-8 -*-
#
# This file is part of Invenio.
#
# Copyright (C) 2022 University Münster.
#
# Invenio is free software; you can redistribute it and/or modify it
# under the terms of the Revised BSD License; see LICENSE file for
# more details.


"""Python API wrapper for the DNB URN service API."""

from .rest_client import DNBUrnServiceRESTClient
from .version import __version__

__all__ = ('DNBUrnServiceRESTClient', '__version__')



# -*- coding: utf-8 -*-
#
# This file is part of Invenio.
#
# Copyright (C) 2022 University Münster.
#
# Invenio is free software; you can redistribute it and/or modify it
# under the terms of the Revised BSD License; see LICENSE file for
# more details.

"""Version information for dnb_urn_service package.

This file is imported by ``dnb_urn_service.__init__``, and parsed by
``setup.py`` as well as ``docs/conf.py``.
"""

from __future__ import absolute_import, print_function

# Do not change the format of this next line. Doing so risks breaking
# setup.py and docs/conf.py

__version__ = "0.1.1"



# -*- coding: utf-8 -*-
#
# This file is part of Invenio.
#
# Copyright (C) 2022 University Münster.
#
# Invenio is free software; you can redistribute it and/or modify it
# under the terms of the Revised BSD License; see LICENSE file for
# more details.

"""Errors for the DNB URN service API."""


class HttpError(Exception):
    """Exception raised when a connection problem happens."""


class DNBURNServiceError(Exception):
    """Exception raised when the server returns a known HTTP error code."""

    @staticmethod
    def factory(err_code, *args):
        """Create exceptions through a Factory based on the HTTP error code."""
        if err_code == 400:
            return DNBURNServiceNotValidError
        if err_code == 401:
            return DNBURNServiceUserNotAuthenticatedError
        if err_code == 403:
            return DNBURNServiceUserNotAuthorizedError
        if err_code == 404:
            return DNBURNServiceUrnNotRegisteredError
        if err_code == 409:
            return DNBURNServiceConflictError
        else:
            return DNBURNServiceServerError


class DNBURNServiceServerError(DNBURNServiceError):
    """An internal server error happened on the DNB end. Try later.

    Base class for all 5XX-related HTTP error codes.
    """


class DNBURNServiceNotValidError(DNBURNServiceError):
    """The information is not valid.

    Base class for 400-related HTTP error code.
    """


class DNBURNServiceUserNotAuthenticatedError(DNBURNServiceError):
    """The user is not authenticated.

    Base class for 401-related HTTP error code.
    """


class DNBURNServiceUserNotAuthorizedError(DNBURNServiceError):
    """The user is not authorized.

    Base class for 403-related HTTP error code.
    """


class DNBURNServiceUrnNotRegisteredError(DNBURNServiceError):
    """The requested URN is not registered.

    Base class for 404-related HTTP error code.
    """


class DNBURNServiceConflictError(DNBURNServiceError):
    """The requested URN is already registered.

    Base class for 409-related HTTP error code.
    """



# -*- coding: utf-8 -*-
#
# This file is part of Invenio.
#
# Copyright (C) 2022 University Münster.
#
# Invenio is free software; you can redistribute it and/or modify it
# under the terms of the Revised BSD License; see LICENSE file for
# more details.

"""Python API client wrapper for the DNB URN service API."""

import os

from setuptools import find_packages, setup

readme = open('README.rst').read()
history = open('CHANGES.rst').read()

tests_require = [
    'responses>=0.10.6',
    'mock>=1.3.0',
    'pytest>=7.1.3',
    'pytest-invenio>=1.4.0',
]

extras_require = {
    'docs': [
        'Sphinx>=3',
    ],
    'tests': tests_require,
}

extras_require['all'] = []
for reqs in extras_require.values():
    extras_require['all'].extend(reqs)

setup_requires = [
    'pytest-runner>=2.6.2',
]

install_requires = [
    'jsonschema>=3.0.0',
    'lxml>=4.5.0',
    'requests>=2.12.2',
    'idutils>=1.2.0'
]

packages = find_packages()

# Get the version string. Cannot be done with import!
g = {}
with open(os.path.join('dnb_urn_service', 'version.py'), 'rt') as fp:
    exec(fp.read(), g)
    version = g['__version__']

setup(
    name='dnb_urn_service',
    license='MIT',
    version=version,
    description=__doc__,
    long_description=readme + '\n\n' + history,
    author='University Münster',
    author_email='gressho@uni-muenster.de',
    url='https://github.com/ulbmuenster/dnb-urn-service',
    include_package_data=True,
    packages=packages,
    zip_safe=False,
    extras_require=extras_require,
    install_requires=install_requires,
    setup_requires=setup_requires,
    tests_require=tests_require,
    classifiers=[
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Topic :: Utilities',
    ],
)
